/*	--*- c -*--
 * Copyright (C) 2014 Enrico Scholz <enrico.scholz@sigma-chemnitz.de>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 3 of the License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef H_VITA1300_CONVERT_H
#define H_VITA1300_CONVERT_H

enum vita1300_subsampling_mode {
	VITA1300_SUBSAMPLING_NONE,
	VITA1300_SUBSAMPLING_MONO,
	VITA1300_SUBSAMPLING_COLOR,
};

enum vita1300_result {
	VITA1300_RES_OK,
	VITA1300_BAD_X,
	VITA1300_BAD_MODE,
	VITA1300_BAD_BPP,
	VITA1300_BAD_OVERLAP
};

/** Remaps pixels captured by VITA 3000 sensor
 *
 *  \param dst  Destination buffer; it must be either the same as \c src or
 *              both buffers must be completely distinct
 *  \param src  Source buffer; it must be either the same as \c dst or both
 *              buffers must be completely distinct
 *  \param mode Subsampling mode
 *  \param w    Width of image in pixels
 *  \param h    Height of image in lines
 *  \param bpp  Bits per pixel
 *
 *  \retval VITA1300_RES_OK   buffer was remapped successful
 *  \retval VITA1300_BAD_X    width \c x of image is invalid for the selected
 *                            subsampling mode
 *  \retval VITA1300_BAD_MODE unsupported subsampling mode \c mode
 *  \retval VITA1300_BAD_BPP  unsupported \c bpp; it must be in the range of 8
 *                            till 16
 *  \retval VITA1300_BAD_OVERLAP the \c src and \dst buffers overlap partially
 */
enum vita1300_result vita1300_convert(void *dst, void const *src,
				      enum vita1300_subsampling_mode mode,
				      unsigned int w, unsigned int h, 
				      unsigned int bpp);

#endif	/* H_VITA1300_CONVERT_H */
